/*
 * Copyright (c) 2006-2015 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_swing.components;

import java.awt.Dimension;
import java.awt.Insets;

import javax.swing.BorderFactory;
import javax.swing.Icon;
import javax.swing.JButton;

/**
 * Image button, also has the ability to hold an object.
 *
 * @param <T> Type of object the button holds.
 */
public class ImageButton<T> extends JButton {

    /** A version number for this class. */
    private static final long serialVersionUID = 2;
    /** Button object. */
    private T object;

    /**
     * Creates a new instance of ImageButton.
     *
     * @param actionCommand Action command for the button
     * @param icon          Normal icon for the button
     */
    public ImageButton(final String actionCommand, final Icon icon) {
        this(actionCommand, icon, icon);
    }

    /**
     * Creates a new instance of ImageButton.
     *
     * @param actionCommand Action command for the button
     * @param icon          Normal icon for the button
     * @param rolloverIcon  Rollover icon for the button
     */
    public ImageButton(final String actionCommand, final Icon icon,
            final Icon rolloverIcon) {
        this(actionCommand, icon, rolloverIcon, rolloverIcon);
    }

    /**
     * Creates a new instance of ImageButton.
     *
     * @param actionCommand Action command for the button
     * @param icon          Normal icon for the button
     * @param rolloverIcon  Rollover icon for the button
     * @param pressedIcon   Pressed icon for the button
     */
    public ImageButton(final String actionCommand, final Icon icon,
            final Icon rolloverIcon, final Icon pressedIcon) {

        setIcon(icon);
        setRolloverIcon(rolloverIcon);
        setPressedIcon(pressedIcon);
        setContentAreaFilled(false);
        setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 0));
        setMargin(new Insets(0, 0, 0, 0));
        setPreferredSize(new Dimension(16, 16));
        setActionCommand(actionCommand);
    }

    /**
     * Sets all the image buttons icons.
     *
     * @param icon New icon
     */
    public void setIcons(final Icon icon) {
        setIcon(icon);
        setRolloverIcon(icon);
        setPressedIcon(icon);
    }

    /**
     * Sets the object for this button.
     *
     * @param object Object to hold
     */
    public void setObject(final T object) {
        this.object = object;
    }

    /**
     * Gets this buttons object.
     *
     * @return This button's object
     */
    public T getObject() {
        return object;
    }

}
