/*
 * Copyright (c) 2006-2015 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_swing.components.statusbar;

import com.dmdirc.updater.UpdateComponent;
import com.dmdirc.updater.manager.CachingUpdateManager;
import com.dmdirc.updater.manager.UpdateStatus;

import java.awt.Window;

import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * Information popup for the updater label.
 *
 * @since 0.6.3
 */
public class UpdaterPopup extends StatusbarPopupWindow {

    /** A version number for this class. */
    private static final long serialVersionUID = 1;
    /** The update manager to use to retrieve update status. */
    private final CachingUpdateManager updateManager;

    /**
     * Creates a new popup window for the specified panel and window.
     *
     * @param updateManager The manager to use to get update information.
     * @param parent        The panel that owns this popup
     * @param parentWindow  The Window that owns this popup
     */
    public UpdaterPopup(
            final CachingUpdateManager updateManager,
            final JPanel parent,
            final Window parentWindow) {
        super(parent, parentWindow);

        this.updateManager = updateManager;
    }

    @Override
    protected void initContent(final JPanel panel) {
        for (UpdateComponent component : updateManager.getComponents()) {
            final UpdateStatus status = updateManager.getStatus(component);

            if (status != UpdateStatus.IDLE && status != UpdateStatus.CHECKING_NOT_PERMITTED) {
                panel.add(new JLabel(component.getFriendlyName()),
                        "growx, pushx");
                panel.add(new JLabel(status.getDescription()),
                        "growx, pushx, wrap");
            }
        }
    }

}
