/*
 * Copyright (c) 2006-2015 DMDirc Developers
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.dmdirc.addons.ui_web2.serialisers;

import com.dmdirc.interfaces.WindowModel;
import com.dmdirc.ui.WindowManager;

import com.google.gson.JsonElement;
import com.google.gson.JsonObject;
import com.google.gson.JsonSerializationContext;
import com.google.gson.JsonSerializer;

import java.lang.reflect.Type;

import javax.inject.Inject;

/**
 * Serialises {@link WindowModel}s.
 */
public class WindowModelSerialiser implements JsonSerializer<WindowModel> {

    private final WindowManager windowManager;

    @Inject
    public WindowModelSerialiser(final WindowManager windowManager) {
        this.windowManager = windowManager;
    }

    @Override
    public JsonElement serialize(final WindowModel src, final Type typeOfSrc, final JsonSerializationContext context) {
        final JsonObject res = new JsonObject();
        res.addProperty("id", src.getId());
        res.addProperty("name", src.getName());
        res.addProperty("icon", src.getIcon());
        res.addProperty("title", src.getTitle());
        res.addProperty("writable", src.getInputModel().isPresent());
        res.add("children", context.serialize(windowManager.getChildren(src)));
        res.add("components", context.serialize(src.getComponents()));
        res.add("backbuffer", context.serialize(src.getBackBuffer()));
        return res;
    }

}
